from unittest import TestCase
from pyspark.sql import SparkSession
from pii_anonymizer.spark.anonymize.anonymizer import Anonymizer


class TestReplaceAnonymizer(TestCase):
    def setUp(self) -> None:
        self.SPARK = (
            SparkSession.builder.master("local")
            .appName("Test PIIDetector")
            .getOrCreate()
        )

    def test_replace_for_single_analyzer_result(self):
        replace_string = "[REPLACED]"
        test_data_frame = self.SPARK.createDataFrame(
            [("text containing pii", "something else")]
        )
        analyzer_results = ["pii"]
        result = test_data_frame.rdd.map(
            lambda row: Anonymizer.replace(row, replace_string, analyzer_results)
        ).toDF()

        actual = result.collect()[0][0]

        self.assertEqual(actual, f"text containing {replace_string}")

    def test_replace_for_multiple_analyzer_results(self):
        replace_string = "[REPLACED]"
        test_data_frame = self.SPARK.createDataFrame(
            [("text containing pii1 and pii2", "something else")]
        )
        analyzer_results = ["pii1", "pii2"]

        result = test_data_frame.rdd.map(
            lambda row: Anonymizer.replace(row, replace_string, analyzer_results)
        ).toDF()

        actual = result.collect()[0][0]

        self.assertEqual(
            actual, f"text containing {replace_string} and {replace_string}"
        )



from unittest import TestCase

from pii_anonymizer.common.config_validator import validate, anonymize_mode_err_msg


class TestConfigValidator(TestCase):
    def setUp(self):
        self.config_validator = validate

    def test_should_throw_when_invalid_config(self):
        config = {
            "acquire": {"file_path": "./test_data/test_data.csv", "delimiter": ","},
            "analyze": {},
            "report": {"location": "./output", "level": "medium"},
            "anonymize": {"mode": "invalid_mode", "output_file_path": "./output"},
        }
        with self.assertRaises(ValueError) as ve:
            self.config_validator(config)
        self.assertEqual(str(ve.exception), anonymize_mode_err_msg)



import argparse
import os

default_file_path = "pii-anonymizer.json"


def get_args():
    parser = argparse.ArgumentParser()
    parser.add_argument("--config-file", help="config file to run the tool")
    args = parser.parse_args()

    if args.config_file:
        return args.config_file

    if os.path.exists(default_file_path):
        return default_file_path

    raise ValueError(
        f"Config file path or default file required. Please provide config file path or create {default_file_path}"
    )



from unittest import TestCase
from pyspark.sql import SparkSession
from pii_anonymizer.spark.anonymize.anonymizer import Anonymizer
from hashlib import sha256


class TestHashAnonymizer(TestCase):
    def setUp(self) -> None:
        self.SPARK = (
            SparkSession.builder.master("local")
            .appName("Test PIIDetector")
            .getOrCreate()
        )

    def test_hash_for_single_analyzer_result(self):
        test_data_frame = self.SPARK.createDataFrame(
            [("text containing pii", "something else")]
        )
        hashed = sha256("pii".encode("utf-8")).hexdigest()
        analyzer_results = ["pii"]
        result = test_data_frame.rdd.map(
            lambda row: Anonymizer.hash(row, analyzer_results)
        ).toDF()

        actual = result.collect()[0][0]

        self.assertEqual(actual, f"text containing {hashed}")

    def test_hash_for_multiple_analyzer_results(self):
        test_data_frame = self.SPARK.createDataFrame(
            [("text containing pii1 and pii2", "something else")]
        )
        analyzer_results = ["pii1", "pii2"]
        hashed1 = sha256("pii1".encode("utf-8")).hexdigest()
        hashed2 = sha256("pii2".encode("utf-8")).hexdigest()
        result = test_data_frame.rdd.map(
            lambda row: Anonymizer.hash(row, analyzer_results)
        ).toDF()

        actual = result.collect()[0][0]

        self.assertEqual(actual, f"text containing {hashed1} and {hashed2}")



from pii_anonymizer.common.constants import ANONYMIZE

anonymize_mode = ["replace", "hash"]
anonymize_mode_err_msg = f"{ANONYMIZE}'s mode must be {' or '.join(anonymize_mode)}"


def validate(config):
    # Fallback to default (drop)
    if config[ANONYMIZE].get("mode") is None:
        return

    if config[ANONYMIZE]["mode"] not in anonymize_mode:
        raise ValueError(anonymize_mode_err_msg)



from hashlib import sha256


class Anonymizer:
    @staticmethod
    def replace(row, replace_string, pii_list):
        new_row = []
        for cell in row:
            for word in pii_list:
                if word in cell:
                    cell = cell.replace(word, replace_string)
            new_row.append(cell)
        return new_row

    @staticmethod
    def hash(row, pii_list):
        new_row = []
        for cell in row:
            for word in pii_list:
                if word in cell:
                    cell = cell.replace(word, sha256(word.encode("utf-8")).hexdigest())
            new_row.append(cell)
        return new_row
